Error

Enum Error 

#[non_exhaustive]
pub enum Error { MissingApiKey, InvalidRequest(String), Connection(TransportError), Timeout { after: Duration, }, Api(Box<ApiError>), Decode { source: Error, body: Bytes, meta: Box<ResponseMeta>, }, UnexpectedShape { endpoint: &'static str, meta: Box<ResponseMeta>, }, }
SDK error taxonomy, aligned with the official TypeScript classes.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MissingApiKey

No API key in config or TYPESAFE_API_KEY.



InvalidRequest(String)

Client-side validation failed before a network call.



Connection(TransportError)

DNS, TLS, or connection failure (APIConnectionError).



Timeout

The attempt exceeded the configured timeout (APITimeoutError).

Fields

after: Duration

Timeout budget that elapsed.



Api(Box<ApiError>)

Non-2xx HTTP response after retries are exhausted.



Decode

Response body was not valid JSON for the expected type.

Fields

source: Error

Serde error.

body: Bytes

Raw response bytes (never shown in Display).

meta: Box<ResponseMeta>

HTTP metadata from the failing attempt.



UnexpectedShape

JSON parsed but did not have the documented shape.

Fields

endpoint: &'static str

Endpoint that returned the unexpected body.

meta: Box<ResponseMeta>

HTTP metadata from the failing attempt.

Implementations

Source

impl Error

pub fn request_id(&self) -> Option<&str>

x-typesafe-request-id when this error came from an HTTP response.

pub fn status(&self) -> Option<StatusCode>

HTTP status when this error came from an HTTP response.

pub fn attempts(&self) -> Option<u32>

HTTP attempts performed before this error was returned.

pub fn as_api(&self) -> Option<&ApiError>

The API error when this is Self::Api.

pub fn kind(&self) -> Option<ApiErrorKind>

HTTP status class when this is an API error.

pub fn is_rate_limited(&self) -> bool

True when the API returned HTTP 429.

pub fn is_auth(&self) -> bool

True when the API returned HTTP 401.

pub fn is_timeout(&self) -> bool

True when the attempt timed out.

pub fn is_connection(&self) -> bool

True when a transport/connection failure occurred.